@@ -13,7 +13,7 @@ class ClipItem():
         self.List = SubRipItem_List  
         self.start = SubRipItem_List[0].start.TIME_PATTERN % tuple(SubRipItem_List[0].start)
         self.end = SubRipItem_List[self.count-1].end.TIME_PATTERN % tuple(SubRipItem_List[self.count-1].end)
-        self.exactstart=(SubRipItem_List[0].start.minutes*60+SubRipItem_List[0].start.seconds+SubRipItem_List[0].start.milliseconds/1000);
+        self.exactstart=(SubRipItem_List[0].start.hours*3600+SubRipItem_List[0].start.minutes*60+SubRipItem_List[0].start.seconds+SubRipItem_List[0].start.milliseconds/1000);
         self.risetime_sec=0.05
 
 class SubtitlesClip(VideoClip):
